<div align="left" style="position: relative;">
<img src="https://img.icons8.com/external-tal-revivo-duo-tal-revivo/100/external-markdown-a-lightweight-markup-language-with-plain-text-formatting-syntax-logo-duo-tal-revivo.png" align="right" width="30%" style="margin: -20px 0 0 20px;">
<h1>INIA</h1>
<p align="left">
	<em><code>❯ REPLACE-ME</code></em>
</p>
<p align="left">
	<img src="https://img.shields.io/github/license/grnet/inia?style=default&logo=opensourceinitiative&logoColor=white&color=a181e0" alt="license">
	<img src="https://img.shields.io/github/last-commit/grnet/inia?style=default&logo=git&logoColor=white&color=a181e0" alt="last-commit">
	<img src="https://img.shields.io/github/languages/top/grnet/inia?style=default&color=a181e0" alt="repo-top-language">
	<img src="https://img.shields.io/github/languages/count/grnet/inia?style=default&color=a181e0" alt="repo-language-count">
</p>
<p align="left"><!-- default option, no dependency badges. -->
</p>
<p align="left">
	<!-- default option, no dependency badges. -->
</p>
</div>
<br clear="right">

## 🔗 Table of Contents

- [📍 Overview](#-overview)
- [👾 Features](#-features)
- [📁 Project Structure](#-project-structure)
  - [📂 Project Index](#-project-index)
- [🚀 Getting Started](#-getting-started)
  - [☑️ Prerequisites](#-prerequisites)
  - [⚙️ Installation](#-installation)
  - [🤖 Usage](#🤖-usage)
  - [🧪 Testing](#🧪-testing)
- [📌 Project Roadmap](#-project-roadmap)
- [🔰 Contributing](#-contributing)
- [🎗 License](#-license)
- [🙌 Acknowledgments](#-acknowledgments)

---

## 📍 Overview

<code>❯ REPLACE-ME</code>

---

## 👾 Features

<code>❯ REPLACE-ME</code>

---

## 📁 Project Structure

```sh
└── inia/
    ├── .github
    │   └── workflows
    │       └── main.yml
    ├── README.md
    ├── inia
    │   ├── __init__.py
    │   ├── client.py
    │   ├── cloudformation
    │   │   ├── __init__.py
    │   │   └── client.py
    │   ├── codesuite
    │   │   ├── __init__.py
    │   │   └── client.py
    │   ├── controltower
    │   │   ├── __init__.py
    │   │   └── client.py
    │   ├── costexplorer
    │   │   ├── __init__.py
    │   │   └── client.py
    │   ├── rackspace.py
    │   ├── servicecatalog
    │   │   ├── __init__.py
    │   │   └── client.py
    │   ├── singlesignon
    │   │   ├── __init__.py
    │   │   └── client.py
    │   └── stepfunctions
    │       ├── __init__.py
    │       └── client.py
    ├── requirements.txt
    └── setup.py
```

### 📂 Project Index

<details open>
	<summary><b><code>INIA/</code></b></summary>
	<details> <!-- __root__ Submodule -->
		<summary><b>__root__</b></summary>
		<blockquote>
			<table>
			<tr>
				<td><b><a href='https://github.com/grnet/inia/blob/master/requirements.txt'>requirements.txt</a></b></td>
				<td><code>❯ REPLACE-ME</code></td>
			</tr>
			<tr>
				<td><b><a href='https://github.com/grnet/inia/blob/master/setup.py'>setup.py</a></b></td>
				<td><code>❯ REPLACE-ME</code></td>
			</tr>
			</table>
		</blockquote>
	</details>
	<details> <!-- .github Submodule -->
		<summary><b>.github</b></summary>
		<blockquote>
			<details>
				<summary><b>workflows</b></summary>
				<blockquote>
					<table>
					<tr>
						<td><b><a href='https://github.com/grnet/inia/blob/master/.github/workflows/main.yml'>main.yml</a></b></td>
						<td><code>❯ REPLACE-ME</code></td>
					</tr>
					</table>
				</blockquote>
			</details>
		</blockquote>
	</details>
	<details> <!-- inia Submodule -->
		<summary><b>inia</b></summary>
		<blockquote>
			<table>
			<tr>
				<td><b><a href='https://github.com/grnet/inia/blob/master/inia/rackspace.py'>rackspace.py</a></b></td>
				<td><code>❯ REPLACE-ME</code></td>
			</tr>
			<tr>
				<td><b><a href='https://github.com/grnet/inia/blob/master/inia/client.py'>client.py</a></b></td>
				<td><code>❯ REPLACE-ME</code></td>
			</tr>
			</table>
			<details>
				<summary><b>singlesignon</b></summary>
				<blockquote>
					<table>
					<tr>
						<td><b><a href='https://github.com/grnet/inia/blob/master/inia/singlesignon/client.py'>client.py</a></b></td>
						<td><code>❯ REPLACE-ME</code></td>
					</tr>
					</table>
				</blockquote>
			</details>
			<details>
				<summary><b>costexplorer</b></summary>
				<blockquote>
					<table>
					<tr>
						<td><b><a href='https://github.com/grnet/inia/blob/master/inia/costexplorer/client.py'>client.py</a></b></td>
						<td><code>❯ REPLACE-ME</code></td>
					</tr>
					</table>
				</blockquote>
			</details>
			<details>
				<summary><b>servicecatalog</b></summary>
				<blockquote>
					<table>
					<tr>
						<td><b><a href='https://github.com/grnet/inia/blob/master/inia/servicecatalog/client.py'>client.py</a></b></td>
						<td><code>❯ REPLACE-ME</code></td>
					</tr>
					</table>
				</blockquote>
			</details>
			<details>
				<summary><b>cloudformation</b></summary>
				<blockquote>
					<table>
					<tr>
						<td><b><a href='https://github.com/grnet/inia/blob/master/inia/cloudformation/client.py'>client.py</a></b></td>
						<td><code>❯ REPLACE-ME</code></td>
					</tr>
					</table>
				</blockquote>
			</details>
			<details>
				<summary><b>stepfunctions</b></summary>
				<blockquote>
					<table>
					<tr>
						<td><b><a href='https://github.com/grnet/inia/blob/master/inia/stepfunctions/client.py'>client.py</a></b></td>
						<td><code>❯ REPLACE-ME</code></td>
					</tr>
					</table>
				</blockquote>
			</details>
			<details>
				<summary><b>controltower</b></summary>
				<blockquote>
					<table>
					<tr>
						<td><b><a href='https://github.com/grnet/inia/blob/master/inia/controltower/client.py'>client.py</a></b></td>
						<td><code>❯ REPLACE-ME</code></td>
					</tr>
					</table>
				</blockquote>
			</details>
			<details>
				<summary><b>codesuite</b></summary>
				<blockquote>
					<table>
					<tr>
						<td><b><a href='https://github.com/grnet/inia/blob/master/inia/codesuite/client.py'>client.py</a></b></td>
						<td><code>❯ REPLACE-ME</code></td>
					</tr>
					</table>
				</blockquote>
			</details>
		</blockquote>
	</details>
</details>

---

## 🚀 Getting Started

### ☑️ Prerequisites

Before getting started with inia, ensure your runtime environment meets the following requirements:

- **Programming Language:** Python
- **Package Manager:** Pip

### ⚙️ Installation

Install inia using one of the following methods:

**Build from source:**

1. Clone the inia repository:

```sh
❯ git clone https://github.com/grnet/inia
```

2. Navigate to the project directory:

```sh
❯ cd inia
```

3. Install the project dependencies:

**Using `pip`** &nbsp; [<img align="center" src="https://img.shields.io/badge/Pip-3776AB.svg?style={badge_style}&logo=pypi&logoColor=white" />](https://pypi.org/project/pip/)

```sh
❯ pip install -r requirements.txt
```

### 🤖 Usage

Run inia using the following command:
**Using `pip`** &nbsp; [<img align="center" src="https://img.shields.io/badge/Pip-3776AB.svg?style={badge_style}&logo=pypi&logoColor=white" />](https://pypi.org/project/pip/)

```sh
❯ python {entrypoint}
```

### 🧪 Testing

Run the test suite using the following command:
**Using `pip`** &nbsp; [<img align="center" src="https://img.shields.io/badge/Pip-3776AB.svg?style={badge_style}&logo=pypi&logoColor=white" />](https://pypi.org/project/pip/)

```sh
❯ pytest
```

---

## 📌 Project Roadmap

TBD

---

## 🔰 Contributing

- **💬 [Join the Discussions](https://github.com/grnet/inia/discussions)**: Share your insights, provide feedback, or ask questions.
- **🐛 [Report Issues](https://github.com/grnet/inia/issues)**: Submit bugs found or log feature requests for the `inia` project.
- **💡 [Submit Pull Requests](https://github.com/grnet/inia/blob/main/CONTRIBUTING.md)**: Review open PRs, and submit your own PRs.

<details closed>
<summary>Contributing Guidelines</summary>

1. **Fork the Repository**: Start by forking the project repository to your github account.
2. **Clone Locally**: Clone the forked repository to your local machine using a git client.
   ```sh
   git clone https://github.com/grnet/inia
   ```
3. **Create a New Branch**: Always work on a new branch, giving it a descriptive name.
   ```sh
   git checkout -b new-feature-x
   ```
4. **Make Your Changes**: Develop and test your changes locally.
5. **Commit Your Changes**: Commit with a clear message describing your updates.
   ```sh
   git commit -m 'Implemented new feature x.'
   ```
6. **Push to github**: Push the changes to your forked repository.
   ```sh
   git push origin new-feature-x
   ```
7. **Submit a Pull Request**: Create a PR against the original project repository. Clearly describe the changes and their motivations.
8. **Review**: Once your PR is reviewed and approved, it will be merged into the main branch. Congratulations on your contribution!
</details>

<details closed>
<summary>Contributor Graph</summary>
<br>
<p align="left">
   <a href="https://github.com{/grnet/inia/}graphs/contributors">
      <img src="https://contrib.rocks/image?repo=grnet/inia">
   </a>
</p>
</details>

---

## 🎗 License

This project is protected under the [MIT](https://opensource.org/license/mit) License and [Apache 2.0](https://aws.amazon.com/apache-2-0/) License for the code imported from [awscli](https://github.com/aws/aws-cli).

---
